@@ -20,6 +20,16 @@ sub _message {
   return shift->[1];
 }
 
+sub status_line {
+  my $message = "$_[0]";
+
+  ($message =~ /^(?:OK|ERR):/m
+    # Looks like A&A
+    ? $message =~ /\n?(.*?)[\r\n]*$/
+    # LWP or something else, go for the first line
+    : $message =~ /^(.*?)[\r\n]*/)[0];
+}
+
 1;
 
 __END__
@@ -31,7 +41,7 @@ SMS::Send::UK::AA::Response
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
